from ariadne import graphql
from flask import request, jsonify

from api.route import Route
from api_graphql.service.schema import schema
from core.logger import Logger

BasePath = f"/api/graphql"
logger = Logger(__name__)


@Route.post(f"{BasePath}")
async def graphql_endpoint():
    data = request.get_json()

    # Note: Passing the request to the context is optional.
    # In Flask, the current request is always accessible as flask.request
    success, result = await graphql(schema, data, context_value=request)

    status_code = 200
    if "errors" in result:
        status_codes = [
            error.get("extensions", {}).get("code", 200) for error in result["errors"]
        ]
        status_code = max(status_codes, default=200)

    return jsonify(result), status_code
